==> antiright-2.99.6.tar.bz2: antiright/gshterm/command_line.c <==
/*
  AntiRight
  (c) 2007 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gshterm.h"

extern char *gsh_geometry;

char*
gshterm_construct_command(int argc, char **argv)
{
        gchar *command;

        command=""; /* Initialize to empty for
                       the first concatenation.  */

        if(!gshterm_construct_command_from_args(
           argc, argv, &command))
           asprintf(&command, "/bin/sh");

        return(command);
}
gboolean
gshterm_handle_command_line_option(gchar option, gchar *arg)
{
	gboolean exec_reached=FALSE;

	putchar(option);
	assert(arg);
	switch(option)
	{
		case 'e':
			exec_reached=TRUE;
			break;
		case 'g':
			asprintf(&gsh_geometry, arg);
			break;
		default:
			g_printerr("unknown option");
	}

	return(exec_reached);
}

gboolean
gshterm_construct_command_from_args(int argc, char **argv, gchar **command)
{
	int counter;
	gboolean exec_reached;

	puts(*command);

	for(counter=1, exec_reached=FALSE; counter < argc; counter++)
	{
		if(exec_reached)
			asprintf(command, "%s %s ", *command, argv[counter]);
		else if(argv[counter][0] == '-')
			exec_reached=gshterm_handle_command_line_option(
				argv[counter][1], argv[counter+1]);

#ifdef DEBUG
		g_print("\n%d\t%s\n", counter, argv[counter]);
#endif /* DEBUG */

	}

	return(exec_reached);

}

==> antiright-2.99.7.tar.bz2: antiright/gshterm/command_line.c <==
/*
  AntiRight
  (c) 2007 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gshterm.h"

extern char *gsh_geometry;
char *gshterm_font=NULL;

char*
gshterm_construct_command(struct GSHTerm *term, int argc, char **argv)
{
        gchar *command;

        command=""; /* Initialize to empty for
                       the first concatenation.  */

        if(!gshterm_construct_command_from_args(
		term, argc, argv, &command))
           asprintf(&command, "/bin/sh");

        return(command);
}
gboolean
gshterm_handle_command_line_option(
	struct GSHTerm *term, gchar option, gchar *arg)
{
	assert(arg);
	
#ifdef DEBUG
	putchar(option);
#endif /* DEBUG */

	switch(option)
	{
		case 'e':
			return TRUE;
			break;
		case 'f':
			asprintf(&term->font, arg);
			break;
		case 'g':
			asprintf(&term->gsh->geometry, arg);
			break;
		default:
			g_printerr("unknown option: %c\n", option);
	}
	return FALSE;
}

gboolean
gshterm_construct_command_from_args(
	struct GSHTerm *term, int argc, char **argv, gchar **command)
{
	int counter;
	gboolean exec_reached;

#ifdef DEBUG
	puts(*command);
#endif /* DEBUG */

	for(counter=1, exec_reached=FALSE; counter < argc; counter++)
	{
		if(exec_reached)
			asprintf(command, "%s %s ", *command, argv[counter]);
		else if(argv[counter][0] == '-')
			exec_reached=gshterm_handle_command_line_option(
				term, argv[counter][1], argv[counter+1]);

#ifdef DEBUG
		g_print("\n%d\t%s\n", counter, argv[counter]);
#endif /* DEBUG */

	}

	return(exec_reached);
}
